
API Documentation
=================

.. autoexception:: wonderwords.NoWordsToChooseFrom

.. autoclass:: wonderwords.Defaults
    :members:
    :undoc-members:

.. autoclass:: wonderwords.RandomWord
    :members:
    :undoc-members:

.. autoclass:: wonderwords.RandomSentence
    :members:
    :undoc-members:

.. autofunction:: wonderwords.is_profanity

.. autofunction:: wonderwords.filter_profanity
